@@ -1,9 +1,9 @@
-#' Aggregate flows throughout a network.
+#' @title Aggregate flows throughout a network.
 #'
-#' Aggregate flows throughout a network based on an input matrix of flows
-#' between all pairs of `from` and `to` points. Flows are calculated by default
-#' on contracted graphs, via the `contract = TRUE` parameter. (These are
-#' derived by reducing the input graph down to junction vertices only, by
+#' @description Aggregate flows throughout a network based on an input matrix
+#' of flows between all pairs of `from` and `to` points. Flows are calculated
+#' by default on contracted graphs, via the `contract = TRUE` parameter. (These
+#' are derived by reducing the input graph down to junction vertices only, by
 #' joining all intermediate edges between each junction.) If changes to the
 #' input graph do not prompt changes to resultant flows, and the default
 #' `contract = TRUE` is used, it may be that calculations are using previously
@@ -40,16 +40,6 @@
 #' @inheritParams dodgr_dists
 #' @return Modified version of graph with additional `flow` column added.
 #'
-#' @note Spatial Interaction models are often fitted through trialling a range
-#' of values of 'k'. The specification above allows fitting multiple values of
-#' 'k' to be done with a single call, in a way that is far more efficient than
-#' making multiple calls. A matrix of 'k' values may be entered, with each
-#' column holding a different vector of values, one for each 'from' point. For a
-#' matrix of 'k' values having 'n' columns, the return object will be a modified
-#' version in the input 'graph', with an additional 'n' columns, named 'flow1',
-#' 'flow2', ... up to 'n'. These columns must be subsequently matched by the
-#' user back on to the corresponding columns of the matrix of 'k' values.
-#'
 #' @note The `norm_sums` parameter should be used whenever densities at origins
 #' and destinations are absolute values, and ensures that the sum of resultant
 #' flow values throughout the entire network equals the sum of densities at all
@@ -67,7 +57,7 @@
 #' specifying a value via
 #' `RcppParallel::setThreadOptions (numThreads = <desired_number>)`.
 #'
-#' @family distances
+#' @family flows
 #' @export
 #' @examples
 #' graph <- weight_streetnet (hampi)
@@ -246,18 +236,46 @@ dodgr_flows_aggregate <- function (graph,
     return (graph)
 }
 
-#' Aggregate flows dispersed from each point in a network.
+#' @title Aggregate flows dispersed from each point in a network.
 #'
-#' Disperse flows throughout a network based on a input vectors of origin points
-#' and associated densities. Flows are calculated by default on contracted
-#' graphs, via the `contract = TRUE` parameter. (These are derived by reducing
-#' the input graph down to junction vertices only, by joining all intermediate
-#' edges between each junction.) If changes to the input graph do not prompt
-#' changes to resultant flows, and the default `contract = TRUE` is used, it
-#' may be that calculations are using previously cached versions of the
-#' contracted graph. If so, please use either \link{clear_dodgr_cache} to
-#' remove the cached version, or \link{dodgr_cache_off} prior to initial graph
-#' construction to switch the cache off completely.
+#' @description Disperse flows throughout a network based on a input vectors of
+#' origin points and associated densities. Dispersal is implemented as an
+#' exponential decay, controlled by a parameter, `k`, so that flows decay with
+#' `exp(-d / k)`, where `d` is distance. The algorithm allows for efficient
+#' fitting of multiple dispersal models for different coefficients to be fitted
+#' with a single call. Values of the dispersal coefficients, `k`, may take one
+#' of the following forms:
+#'
+#' \itemize{
+#' \item A single numeric value (> 0), with dispersal along all paths
+#' calculated with that single value. Return object (see below) will then have
+#' a single additional column named "flow".
+#' \item A vector of length equal to the number of `from` points, with
+#' dispersal from each point then calculated using the corresponding value of
+#' `k`. Return object has single additional "flow" column.
+#' \item A vector of any other length (that is, >  1 yet different to number of
+#' `from` points), in which case different dispersal models will be fitted for
+#' each of the `n` specified values, and the resultant return object will have
+#' an additional 'n' columns, named 'flow1', 'flow2', ... up to 'n'. These
+#' columns must be subsequently matched by the user back on to the
+#' corresponding 'k' values.
+#' \item A matrix with number of rows equal to the number of `from` points, and
+#' any number of columns. Each column will then specify a distinct dispersal
+#' model, with different values from each row applied to the corresponding
+#' `from` points. The return value will then be the same as the previous
+#' version, with an additional `n` columns, "flow1" to "flown".
+#' }
+#'
+#'
+#' Flows are calculated by default on contracted graphs, via the `contract =
+#' TRUE` parameter. (These are derived by reducing the input graph down to
+#' junction vertices only, by joining all intermediate edges between each
+#' junction.) If changes to the input graph do not prompt changes to resultant
+#' flows, and the default `contract = TRUE` is used, it may be that
+#' calculations are using previously cached versions of the contracted graph.
+#' If so, please use either \link{clear_dodgr_cache} to remove the cached
+#' version, or \link{dodgr_cache_off} prior to initial graph construction to
+#' switch the cache off completely.
 #'
 #' @inheritParams dodgr_flows_aggregate
 #' @param graph `data.frame` or equivalent object representing the network
@@ -275,19 +293,12 @@ dodgr_flows_aggregate <- function (graph,
 #' can be removed by setting `tol = 0`.
 #' @return Modified version of graph with additional `flow` column added.
 #'
-#' @note Spatial Interaction models are often fitted through trialling a range
-#' of values of 'k'. The specification above allows fitting multiple values of
-#' 'k' to be done with a single call, in a way that is far more efficient than
-#' making multiple calls. A matrix of 'k' values may be entered, with each
-#' column holding a different vector of values, one for each 'from' point. For a
-#' matrix of 'k' values having 'n' columns, the return object will be a modified
-#' version in the input 'graph', with an additional 'n' columns, named 'flow1',
-#' 'flow2', ... up to 'n'. These columns must be subsequently matched by the
-#' user back on to the corresponding columns of the matrix of 'k' values.
-#'
-#' @family distances
+#' @family flows
 #' @export
 #' @examples
+#' # This is generally needed to explore different values of `k` on same graph:
+#' dodgr_cache_off ()
+#'
 #' graph <- weight_streetnet (hampi)
 #' from <- sample (graph$from_id, size = 10)
 #' dens <- rep (1, length (from)) # Uniform densities
@@ -296,6 +307,30 @@ dodgr_flows_aggregate <- function (graph,
 #' # edges. These flows are directed, and can be aggregated to equivalent
 #' # undirected flows on an equivalent undirected graph with:
 #' graph_undir <- merge_directed_graph (graph)
+#'
+#' # Remove `flow` column to avoid warning about over-writing values:
+#' graph$flow <- NULL
+#' # One dispersal coefficient for each origin point:
+#' k <- runif (length (from))
+#' graph <- dodgr_flows_disperse (graph, from = from, dens = dens, k = k)
+#' grep ("^flow", names (graph), value = TRUE)
+#' # single dispersal model; single "flow" column
+#'
+#' # Multiple models, muliple dispersal coefficients:
+#' k <- 1:5
+#' graph$flow <- NULL
+#' graph <- dodgr_flows_disperse (graph, from = from, dens = dens, k = k)
+#' grep ("^flow", names (graph), value = TRUE)
+#' # Rm all flow columns:
+#' graph [grep ("^flow", names (graph), value = TRUE)] <- NULL
+#'
+#' # Multiple models with unique coefficient at each origin point:
+#' k <- matrix (runif (length (from) * 5), ncol = 5)
+#' dim (k)
+#' graph <- dodgr_flows_disperse (graph, from = from, dens = dens, k = k)
+#' grep ("^flow", names (graph), value = TRUE)
+#' # 5 "flow" columns again, but this time different dispersal coefficients each
+#' # each origin point.
 dodgr_flows_disperse <- function (graph,
                                   from,
                                   dens,
@@ -368,6 +403,7 @@ dodgr_flows_disperse <- function (graph,
         tol,
         heap
     )
+
     if (nk == 1) {
         graph$flow <- f
     } else {
@@ -378,34 +414,61 @@ dodgr_flows_disperse <- function (graph,
 
     if (contract) { # map contracted flows back onto full graph
         graph <- uncontract_graph (graph, edge_map, graph_full)
-        graph$flow [is.na (graph$flow)] <- 0
     }
+
+    flow_cols <- grep ("^flow", names (graph), value = TRUE)
     if (to_from_indices$compound) {
-        flow_cols <- grep ("^flow", names (graph), value = TRUE)
         graph <- uncompound_junctions (
             graph,
             flow_cols,
             to_from_indices$compound_junction_map
         )
-        graph$flow [is.na (graph$flow)] <- 0
     }
+    graph [, flow_cols] [is.na (graph [, flow_cols])] <- 0
 
     return (graph)
 }
 
-#' Aggregate flows throughout a network using a spatial interaction model.
+#' @title Aggregate flows throughout a network using a spatial interaction model.
 #'
-#' Aggregate flows throughout a network using an exponential Spatial Interaction
-#' (SI) model between a specified set of origin and destination points, and
-#' associated vectors of densities. Flows are calculated by default on
-#' contracted graphs, via the `contract = TRUE` parameter. (These are derived
-#' by reducing the input graph down to junction vertices only, by joining all
-#' intermediate edges between each junction.) If changes to the input graph do
-#' not prompt changes to resultant flows, and the default `contract = TRUE` is
-#' used, it may be that calculations are using previously cached versions of
-#' the contracted graph. If so, please use either \link{clear_dodgr_cache} to
-#' remove the cached version, or \link{dodgr_cache_off} prior to initial graph
-#' construction to switch the cache off completely.
+#' @description Aggregate flows throughout a network using an exponential
+#' Spatial Interaction (SI) model between a specified set of origin and
+#' destination points, and associated vectors of densities. Spatial
+#' interactions are implemented using an exponential decay, controlled by a
+#' parameter, `k`, so that interactions decay with `exp(-d / k)`, where `d` is
+#' distance. The algorithm allows for efficient fitting of multiple interaction
+#' models for different coefficients to be fitted with a single call. Values of
+#' the interaction coefficients, `k`, may take one of the following forms:
+#'
+#' \itemize{
+#' \item A single numeric value (> 0), with interactions along all paths
+#' calculated with that single value. Return object (see below) will then have
+#' a single additional column named "flow".
+#' \item A vector of length equal to the number of `from` points, with
+#' interactions from each point then calculated using the corresponding value
+#' of `k`. Return object has single additional "flow" column.
+#' \item A vector of any other length (that is, >  1 yet different to number of
+#' `from` points), in which case different interaction models will be fitted
+#' for each of the `n` specified values, and the resultant return object will
+#' have an additional 'n' columns, named 'flow1', 'flow2', ... up to 'n'. These
+#' columns must be subsequently matched by the user back on to the
+#' corresponding 'k' values.
+#' \item A matrix with number of rows equal to the number of `from` points, and
+#' any number of columns. Each column will then specify a distinct interaction
+#' model, with different values from each row applied to the corresponding
+#' `from` points. The return value will then be the same as the previous
+#' version, with an additional `n` columns, "flow1" to "flown".
+#' }
+#'
+#' Flows are calculated by default on contracted graphs, via the `contract =
+#' TRUE` parameter. (These are derived by reducing the input graph down to
+#' junction vertices only, by joining all intermediate edges between each
+#' junction.) If changes to the input graph do not prompt changes to resultant
+#' flows, and the default `contract = TRUE` is used, it may be that
+#' calculations are using previously cached versions of the contracted graph.
+#' If so, please use either \link{clear_dodgr_cache} to remove the cached
+#' version, or \link{dodgr_cache_off} prior to initial graph construction to
+#' switch the cache off completely.
 #'
 #' @inheritParams dodgr_flows_aggregate
 #' @param k Width of exponential spatial interaction function (exp (-d / k)),
@@ -417,16 +480,6 @@ dodgr_flows_disperse <- function (graph,
 #' @param dens_to Vector of densities at destination ('to') points
 #' @return Modified version of graph with additional `flow` column added.
 #'
-#' @note Spatial Interaction models are often fitted through trialling a range
-#' of values of 'k'. The specification above allows fitting multiple values of
-#' 'k' to be done with a single call, in a way that is far more efficient than
-#' making multiple calls. A matrix of 'k' values may be entered, with each
-#' column holding a different vector of values, one for each 'from' point. For a
-#' matrix of 'k' values having 'n' columns, the return object will be a modified
-#' version in the input 'graph', with an additional 'n' columns, named 'flow1',
-#' 'flow2', ... up to 'n'. These columns must be subsequently matched by the
-#' user back on to the corresponding columns of the matrix of 'k' values.
-#'
 #' @note The `norm_sums` parameter should be used whenever densities at origins
 #' and destinations are absolute values, and ensures that the sum of resultant
 #' flow values throughout the entire network equals the sum of densities at all
@@ -446,17 +499,24 @@ dodgr_flows_disperse <- function (graph,
 #' anywhere in a network within machine tolerance. Such cases may result in sums
 #' of output flows being less than sums of input densities.
 #'
-#' @family distances
+#' @family flows
 #' @export
 #' @examples
+#' # This is generally needed to explore different values of `k` on same graph:
+#' dodgr_cache_off ()
+#'
 #' graph <- weight_streetnet (hampi)
 #' from <- sample (graph$from_id, size = 10)
-#' to <- sample (graph$to_id, size = 5)
-#' to <- to [!to %in% from]
-#' flows <- matrix (10 * runif (length (from) * length (to)),
-#'     nrow = length (from)
+#' to <- sample (graph$from_id, size = 20)
+#' dens_from <- runif (length (from))
+#' dens_to <- runif (length (to))
+#' graph <- dodgr_flows_si (
+#'     graph,
+#'     from = from,
+#'     to = to,
+#'     dens_from = dens_from,
+#'     dens_to = dens_to
 #' )
-#' graph <- dodgr_flows_aggregate (graph, from = from, to = to, flows = flows)
 #' # graph then has an additonal 'flows' column of aggregate flows along all
 #' # edges. These flows are directed, and can be aggregated to equivalent
 #' # undirected flows on an equivalent undirected graph with:
@@ -464,6 +524,51 @@ dodgr_flows_disperse <- function (graph,
 #' # This graph will only include those edges having non-zero flows, and so:
 #' nrow (graph)
 #' nrow (graph_undir) # the latter is much smaller
+#'
+#' # ----- One dispersal coefficient for each origin point:
+#' # Remove `flow` column to avoid warning about over-writing values:
+#' graph$flow <- NULL
+#' k <- runif (length (from))
+#' graph <- dodgr_flows_si (
+#'     graph,
+#'     from = from,
+#'     to = to,
+#'     dens_from = dens_from,
+#'     dens_to = dens_to,
+#'     k = k
+#' )
+#' grep ("^flow", names (graph), value = TRUE)
+#' # single dispersal model; single "flow" column
+#'
+#' # ----- Multiple models, muliple dispersal coefficients:
+#' k <- 1:5
+#' graph$flow <- NULL
+#' graph <- dodgr_flows_si (
+#'     graph,
+#'     from = from,
+#'     to = to,
+#'     dens_from = dens_from,
+#'     dens_to = dens_to,
+#'     k = k
+#' )
+#' grep ("^flow", names (graph), value = TRUE)
+#' # Rm all flow columns:
+#' graph [grep ("^flow", names (graph), value = TRUE)] <- NULL
+#'
+#' # Multiple models with unique coefficient at each origin point:
+#' k <- matrix (runif (length (from) * 5), ncol = 5)
+#' dim (k)
+#' graph <- dodgr_flows_si (
+#'     graph,
+#'     from = from,
+#'     to = to,
+#'     dens_from = dens_from,
+#'     dens_to = dens_to,
+#'     k = k
+#' )
+#' grep ("^flow", names (graph), value = TRUE)
+#' # 5 "flow" columns again, but this time different dispersal coefficients each
+#' # each origin point.
 dodgr_flows_si <- function (graph,
                             from,
                             to,
@@ -557,8 +662,9 @@ dodgr_flows_si <- function (graph,
 
     if (contract) { # map contracted flows back onto full graph
         graph <- uncontract_graph (graph, edge_map, graph_full)
-        graph$flow [is.na (graph$flow)] <- 0
     }
+
+    flow_cols <- grep ("^flow", names (graph), value = TRUE)
     if (to_from_indices$compound) {
         flow_cols <- grep ("^flow", names (graph), value = TRUE)
         graph <- uncompound_junctions (
@@ -566,8 +672,8 @@ dodgr_flows_si <- function (graph,
             flow_cols,
             to_from_indices$compound_junction_map
         )
-        graph$flow [is.na (graph$flow)] <- 0
     }
+    graph [, flow_cols] [is.na (graph [, flow_cols])] <- 0
 
     return (graph)
 }
