@@ -46,6 +46,10 @@ dodgr_contract_graph <- function (graph, verts = NULL, nocache = FALSE) {
             stop ("verts must be a single value or a vector of vertex IDs")
         }
         if (!is.character (verts)) {
+            message (
+                "'verts' will be presumed to be character labels",
+                " matching 'id' columns of 'dodgr_vertices()'."
+            )
             verts <- paste0 (verts)
         }
         verts <- verts [which (verts %in% v$id)]
@@ -120,48 +124,49 @@ dodgr_contract_graph_internal <- function (graph, v, verts = NULL) {
     graph_contracted <-
         rm_edges_with_heterogenous_data (graph, graph_contracted, gr_cols)
 
+    # Contracted graph can still contain duplicated edges. Deduplication
+    # reduces all duplicates to shortest weighted distance.
+    graph_contracted$graph <- dodgr_deduplicate_graph (graph_contracted$graph)
+    index <- which (!graph_contracted$edge_map$edge_new %in% graph_contracted$graph$edge_id)
+    graph_contracted$edge_map <- graph_contracted$edge_map [-(index), ]
+
     # graph_contracted$graph has only 5 cols of (edge_id, from, to, d, w). These
     # have to be matched onto original graph.  This is done by using edge_map to
-    # get matching indices into both contracted and original graph:
-    indx_contr <- match (
-        graph_contracted$edge_map$edge_new,
-        graph_contracted$graph$edge_id
+    # map new contracted "edge_id" values to first matching edge or original graph.
+    index_to_orig_edges <- match (graph_contracted$graph$edge_id, graph [[gr_cols$edge_id]])
+    index_na <- which (is.na (index_to_orig_edges)) # contracted edges
+    index_to_contracted_edges <- match (
+        graph_contracted$graph$edge_id [index_na],
+        graph_contracted$edge_map$edge_new
     )
-    indx_orig <- match (
-        graph_contracted$edge_map$edge_old,
-        graph [, gr_cols$edge_id]
-    )
-    # Then reduce the latter only to the corresponding first non-repeated values
-    # of the former.
-    indx_orig <- indx_orig [which (!duplicated (indx_contr))]
+    old_edges <- graph_contracted$edge_map$edge_old [index_to_contracted_edges]
+    index_to_orig_edges [index_na] <- match (old_edges, graph [[gr_cols$edge_id]])
+
+    graph_refill <- graph [index_to_orig_edges, ]
 
-    indx_contr <- unique (indx_contr)
-    graph_refill <- graph [indx_orig, ]
     graph_refill [, gr_cols$edge_id] <-
-        graph_contracted$graph$edge_id [indx_contr]
-    graph_refill [, gr_cols$from] <- graph_contracted$graph$from [indx_contr]
-    graph_refill [, gr_cols$to] <- graph_contracted$graph$to [indx_contr]
-    graph_refill [, gr_cols$d] <- graph_contracted$graph$d [indx_contr]
+        graph_contracted$graph$edge_id
+    graph_refill [, gr_cols$from] <- graph_contracted$graph$from
+    graph_refill [, gr_cols$to] <- graph_contracted$graph$to
+    graph_refill [, gr_cols$d] <- graph_contracted$graph$d
     graph_refill [, gr_cols$d_weighted] <-
-        graph_contracted$graph$d_weighted [indx_contr]
+        graph_contracted$graph$d_weighted
     if (!is.na (gr_cols$time) && !is.na (gr_cols$time_weighted)) {
         graph_refill [, gr_cols$time] <-
-            graph_contracted$graph$time [indx_contr]
+            graph_contracted$graph$time
         graph_refill [, gr_cols$time_weighted] <-
-            graph_contracted$graph$timew [indx_contr]
+            graph_contracted$graph$timew
     }
 
     # Then re-insert spatial coordinates
     if (is_graph_spatial (graph)) {
         spcols <- find_spatial_cols (graph)$fr_col
-        indx <- match (graph_contracted$graph$from [indx_contr], graph2$from)
-        graph_refill [, spcols [1]] <- graph [indx, spcols [1]] # nolint
-        graph_refill [, spcols [2]] <- graph [indx, spcols [2]] # nolint
+        graph_refill [, spcols [1]] <- graph [index_to_orig_edges, spcols [1]] # nolint
+        graph_refill [, spcols [2]] <- graph [index_to_orig_edges, spcols [2]] # nolint
 
         spcols <- find_spatial_cols (graph)$to_col
-        indx <- match (graph_contracted$graph$to [indx_contr], graph2$to)
-        graph_refill [, spcols [1]] <- graph [indx, spcols [1]] # nolint
-        graph_refill [, spcols [2]] <- graph [indx, spcols [2]] # nolint
+        graph_refill [, spcols [1]] <- graph [index_to_orig_edges, spcols [1]] # nolint
+        graph_refill [, spcols [2]] <- graph [index_to_orig_edges, spcols [2]] # nolint
         # This code matches way_id values to those in original graph, but that's
         # kind of arbitrary because with duplicated ways the ID matching can
         # never be systematically controlled
@@ -177,11 +182,6 @@ dodgr_contract_graph_internal <- function (graph, v, verts = NULL) {
         # }
     }
 
-    # and finally replicate the uncontracted edges of graph in graph_contracted
-    indx_uncontr <- which (!graph [, gr_cols$edge_id] %in%
-        graph_contracted$edge_map$edge_old)
-    graph_refill <- rbind (graph_refill, graph [indx_uncontr, ])
-
     if (any (grepl ("comp", names (graph), ignore.case = TRUE))) {
         ci <- which (grepl ("comp", names (graph_refill), ignore.case = TRUE))
         cnm <- names (graph_refill) [ci]
@@ -259,10 +259,20 @@ rm_edges_with_heterogenous_data <- function (graph, graph_contracted, gr_cols) {
 #' Re-expand a contracted graph.
 #'
 #' Revert a contracted graph created with \link{dodgr_contract_graph} back to
-#' the full, uncontracted version. This function is mostly used for the side
+#' a full, uncontracted version. This function is mostly used for the side
 #' effect of mapping any new columns inserted on to the contracted graph back
 #' on to the original graph, as demonstrated in the example.
 #'
+#' Note that this function will generally *not* recover original graphs
+#' submitted to \link{dodgr_contract_graph}. Specifically, the sequence
+#' `dodgr_contract_graph(graph) |> dodgr_uncontract_graph()` will generally
+#' produce a graph with fewer edges than the original. This is because graphs
+#' may have multiple paths between a given pair of points. Contraction will
+#' reduce these to the single path with the shortest weighted distance (or
+#' time), and uncontraction will restore only that single edge with shortest
+#' weighted distance, and not any original edges which may have had longer
+#' weighted distances.
+#'
 #' @param graph A contracted graph created from \link{dodgr_contract_graph}.
 #'
 #' @return A single `data.frame` representing the equivalent original,
