@@ -186,12 +186,12 @@ match_pts_to_graph <- function (graph, xy,
 #' @inherit match_pts_to_graph
 #' @family match
 #' @export
-match_points_to_graph <- function (graph, xy, connected = FALSE) {
+match_points_to_graph <- function (graph, xy, connected = FALSE, distances = FALSE) {
 
-    match_pts_to_graph (graph, xy, connected = connected)
+    match_pts_to_graph (graph, xy, connected = connected, distances = distances)
 }
 
-#' Get geodesic distances to intersection points for match_pts_to_graph.
+#' Get  distances to intersection points for match_pts_to_graph.
 #'
 #' @param res Output of 'rcpp_points_index' function
 #' @noRd
@@ -208,11 +208,13 @@ signed_intersection_dists <- function (graph, xy, res) {
         y = res [index + 2L * nrow (xy)]
     )
 
+    measure <- get_geodist_measure (graph)
+
     d <- geodist::geodist (
         xy,
         xy_intersect,
         paired = TRUE,
-        measure = "geodesic"
+        measure = measure
     )
 
     # Then coordinates of graph edges for sign calculation
@@ -274,6 +276,8 @@ add_nodes_to_graph <- function (graph,
                                 dist_tol = 1e-6,
                                 intersections_only = FALSE) {
 
+    measure <- get_geodist_measure (graph)
+
     pts <- match_pts_to_graph (graph, xy, distances = TRUE)
     xy <- pre_process_xy (xy)
     pts$x0 <- xy [, 1]
@@ -331,11 +335,12 @@ add_nodes_to_graph <- function (graph,
                 x = as.numeric (c (edge_i [1, "xfr"], edge_i [1, "xto"], edge_i [2, "xto"])),
                 y = as.numeric (c (edge_i [1, "yfr"], edge_i [1, "yto"], edge_i [2, "yto"]))
             )
-            dmat <- geodist::geodist (xy_i)
+            dmat <- geodist::geodist (xy_i, measure = measure)
 
             d_i <- geodist::geodist (
                 pts [i, c ("x", "y")],
-                pts [i, c ("x0", "y0")]
+                pts [i, c ("x0", "y0")],
+                measure = measure
             )
             d_i <- as.numeric (d_i [1, 1])
 
@@ -361,9 +366,9 @@ add_nodes_to_graph <- function (graph,
                 edge_i$d [1] <- dmat [1, 2]
                 edge_i$d [2] <- dmat [2, 3]
 
-                edge_i$d_weighted <- edge_i$d * d_wt
-                edge_i$time <- edge_i$d * t_scale
-                edge_i$time_weighted <- edge_i$time * t_wt
+                edge_i$d_weighted <- edge_i$d * d_wt [c (e, e)]
+                edge_i$time <- edge_i$d * t_scale [c (e, e)]
+                edge_i$time_weighted <- edge_i$time * t_wt [c (e, e)]
 
                 edge_i$edge_id <- paste0 (
                     edge_i$edge_id,
@@ -384,9 +389,9 @@ add_nodes_to_graph <- function (graph,
                 edge_i_new$yto [2] <- pts$y0 [i]
 
                 edge_i_new$d <- d_i
-                edge_i_new$d_weighted <- d_i * d_wt
-                edge_i_new$time <- d_i * t_scale
-                edge_i_new$time_weighted <- edge_i_new$time * t_wt
+                edge_i_new$d_weighted <- d_i * d_wt [c (e, e)]
+                edge_i_new$time <- d_i * t_scale [c (e, e)]
+                edge_i_new$time_weighted <- edge_i_new$time * t_wt [c (e, e)]
 
                 edge_i_new$edge_id <- vapply (
                     seq_len (nrow (edge_i_new)),
@@ -406,7 +411,7 @@ add_nodes_to_graph <- function (graph,
     edges_split <- do.call (rbind, edges_split)
 
     # Then match edges_split back on to original graph:
-    graph_to_add <- graph_to_add [edges_split$n, ]
+    graph_to_add <- graph_to_add [match (edges_split$n, index$n), ]
     gr_cols <- gr_cols [which (!is.na (gr_cols))]
     for (g in seq_along (gr_cols)) {
         graph_to_add [, gr_cols [g]] <- edges_split [[names (gr_cols) [g]]]
