@@ -45,9 +45,13 @@ sc_edge_dist <- function (graph) {
     # no visible binding notes:
     .vx0_z <- .vx1_z <- NULL
 
+    # Get geodist measure, noting that graph has no hash at this stage, so full
+    # calculation will be executed.
+    measure <- get_geodist_measure (graph)
+
     xy0 <- as.data.frame (graph [, c (".vx0_x", ".vx0_y")])
     xy1 <- as.data.frame (graph [, c (".vx1_x", ".vx1_y")])
-    graph$d <- geodist::geodist (xy0, xy1, paired = TRUE, measure = "geodesic")
+    graph$d <- geodist::geodist (xy0, xy1, paired = TRUE, measure = measure)
     if (".vx0_z" %in% names (graph) && ".vx1_z" %in% names (graph)) {
         graph <- dplyr::mutate (graph, "dz" = .vx1_z - .vx0_z) %>%
             dplyr::select (-c (.vx0_z, .vx1_z))
@@ -113,11 +117,24 @@ convert_hw_types_to_bool <- function (graph, wt_profile) {
 
 set_oneway_bike_flags <- function (graph, bikeflags, wt_profile) {
 
-    index <- which (!graph$oneway %in% c ("no", "yes"))
-    if (length (index) > 0) {
-        graph$oneway [index] <- "no"
+    oneway_keys <- tolower (substring (names (table (graph$oneway)), 1, 1))
+    if (length (oneway_keys) > 2L) {
+        warning (
+            "'oneway' column has ambiguous values; ",
+            "should be TRUE/FALSE or 'yes'/'no' only",
+            call. = FALSE
+        )
+        oneway_keys <- oneway_keys [which (oneway_keys %in% c ("0", "1", "y", "n", "t", "f"))]
+    }
+    if (all (oneway_keys %in% c ("0", "1"))) {
+        graph$oneway <- as.logical (graph$oneway)
+    } else if (all (oneway_keys %in% c ("y", "n"))) {
+        graph$oneway <- tolower (substring (graph$oneway, 1, 1))
+        graph$oneway <- ifelse (graph$oneway == "y", TRUE, FALSE)
+    } else if (all (oneway_keys %in% c ("t", "f"))) {
+        graph$oneway <- tolower (substring (graph$oneway, 1, 1))
+        graph$oneway <- ifelse (graph$oneway == "t", TRUE, FALSE)
     }
-    graph$oneway <- ifelse (graph$oneway == "no", FALSE, TRUE)
 
     if (length (bikeflags) == 1) {
         # oneway:bicycle doesn't enquote properly, so:
